@@ -28,10 +28,6 @@ GType ev_job_page_data_flags_get_type (void) G_GNUC_CONST;
 /* enumerations from "ev-job-scheduler.h" */
 GType ev_job_priority_get_type (void) G_GNUC_CONST;
 #define EV_TYPE_JOB_PRIORITY (ev_job_priority_get_type ())
-
-/* enumerations from "ev-view.h" */
-GType ev_view_selection_mode_get_type (void) G_GNUC_CONST;
-#define EV_TYPE_VIEW_SELECTION_MODE (ev_view_selection_mode_get_type ())
 G_END_DECLS
 
 #endif /* !EV_VIEW_TYPE_BUILTINS_H */
